import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * The bloodstream is the setting for our White Blood Cell scenario. 
 * It's a place where blood cells, bacteria and Meteoritees float around.
 * 
 * @author Michael Kölling
 * @version 0.1
 */
public class Space extends World
{
    private int score;
    private int time;
    /**
     * Constructor: Set up the staring objects.
     */
    public Space()
    {    
        super(780, 360, 1); 
        setPaintOrder(Border.class);
        prepare();
        score = 0;
        showScore();
        time = 2000;
        showTime();
    }

    private void countTime()
    {
        time--;
        showTime();
        if(time == 0)
        {
            Greenfoot.stop();
            showEndMessage();
        }
    }

    private void showTime()
    {
        showText("Time: " +time, 700, 20);
    }

    /**
     * I have created an addScore method and located it in the World class so that I can 
     * access this method from all of my Actor classes.
     */
    public void addScore(int points)
    {
        score = score + points;
        showScore();
        if(score <= -50)
        {
            Greenfoot.stop();
            Greenfoot.playSound("game-over.wav");
            showEndMessage2();
        }
    }

    private void showScore()
    {
        showText("score:"  + score, 80, 25);
    }

    /**
     * Create new floating objects at irregular intervals.
     */
    public void act()
    { 
        countTime();
        if (Greenfoot.getRandomNumber(100) < 3)
        {
            addObject(new Energy(), 779, Greenfoot.getRandomNumber(360));
        }

        if (Greenfoot.getRandomNumber(100) < 2)
        {
            addObject(new Lining(), 779, 359);
            addObject(new Lining(), 779, 0);
        }

        if (Greenfoot.getRandomNumber(100) < 1)
        {
            addObject(new Meteorite(), 779,Greenfoot.getRandomNumber(360));
        }

        if (Greenfoot.getRandomNumber(100) < 6)
        {
            addObject(new Star(), 779, Greenfoot.getRandomNumber(360));
        }
    }
    /**
     * show the end-of-game message on screen.
     */
    private void showEndMessage()
    {
        showText("Time is up - you win!" , 390 ,150);
        showText("Your final score: " + score + " points", 390, 170);
    }
    private void showEndMessage2()
    {
        showText("You lose!" , 390 ,150);
        showText("Try again next time!", 390, 170);
    }
    /**
     * Prepare the world for the start of the program. In this case: Create
     * a white blood cell and the lining at the edge of the blood stream.
     */
    private void prepare()
    {
        SpaceShip SpaceShip = new SpaceShip();
        addObject(SpaceShip, 97, 179);
        Lining lining = new Lining();
        addObject(lining, 126, 1);
        Lining lining2 = new Lining();
        addObject(lining2, 342, 5);
        Lining lining3 = new Lining();
        addObject(lining3, 589, 2);
        Lining lining4 = new Lining();
        addObject(lining4, 695, 5);
        Lining lining5 = new Lining();
        addObject(lining5, 114, 359);
        Lining lining6 = new Lining();
        Lining lining7 = new Lining();
        addObject(lining7, 295, 353);
        Lining lining8 = new Lining();
        Lining lining9 = new Lining();
        Lining lining10 = new Lining();
        addObject(lining10, 480, 358);
        Lining lining11 = new Lining();
        addObject(lining11, 596, 359);
        Lining lining12 = new Lining();
        addObject(lining12, 740, 354);
        Border border = new Border();
        addObject(border, 0, 180);
        Border border2 = new Border();
        addObject(border2, 770, 180);
    }
}
